@@ -8,6 +8,8 @@ from corens.ns import nsGet
 from corens.mod import F as _F
 from corens.mod import f as _f
 from corens.mod import lf as lf
+from corens.mod import p as p
+
 
 
 from corens.cfg import nsDefaults
@@ -19,6 +21,7 @@ def NS(*args, **kw):
     ns = nsImport(ns, nsGet(ns, "/config/library"))
     cargs = kw.get('args', sys.argv[1:])
     _f(ns, "/bin/args")(cargs)
+    _f(ns, "/sbin/signalinit")(*args, **kw)
     _f(ns, "/sbin/envinit")(*args, **kw)
     for c in nsGet(ns, "/config/cfg.files"):
         _f(ns, "/bin/Cfg")(c)
@@ -27,8 +30,10 @@ def NS(*args, **kw):
     _f(ns, "/sbin/network_init")(*args, **kw)
     _f(ns, "/sbin/vnsinit")(*args, **kw)
     _f(ns, "/sbin/hyinit")(*args, **kw)
-    _f(ns, "/sbin/init")(*args, **kw)
     _f(ns, "/sbin/hy.startup")(*args, **kw)
+    _f(ns, "/sbin/signalsetup")(*args, **kw)
+    _f(ns, "/sbin/envsetup")()
+    _f(ns, "/sbin/init")(*args, **kw)
     _f(ns, "/bin/cmd")(*args, **kw)
     if nsGet(ns, "/config/cmd.run") is False:
             _f(ns, "/bin/main")(*args, **kw)
