@@ -1,11 +1,14 @@
 
 import gevent
+from Cheetah.Template import Template
 from clint.textui import indent, puts, colored
 from corens.ns import nsGet
 
 
 def nsConsole(ns,  msg, **kw):
     _msg = msg % kw
+    if nsGet(ns, "/etc/console") is False:
+        return _msg
     q = nsGet(ns, "/sys/console")
     q.put_nowait(_msg)
     return _msg
@@ -25,6 +28,10 @@ def nsConsoleProcess(ns, entries=1):
             break
         gevent.sleep(0.1)
 
+def nsConsoleDaemon(ns):
+    while True:
+        pass
+
 def nsConsoleSize(ns):
     q = nsGet(ns, "/sys/console")
     return q.qsize()
