@@ -17,11 +17,15 @@ def NS(**kw):
     nsMkdir(ns, "/config")
     nsMkdir(ns, "/etc")
     nsSet(ns, "/etc/fs", {})
+    nsSet(ns, "/etc/console", True)
+    nsSet(ns, "/etc/log", True)
     nsMkdir(ns, "/etc/init.d")
     nsMkdir(ns, "/etc/args")
     nsMkdir(ns, "/help")
     nsMkdir(ns, "/help/cmd")
     nsMkdir(ns, "/bin")
+    nsMkdir(ns, "/bin/signals")
+    nsMkdir(ns, "/bin/atexit")
     nsMkdir(ns, "/sbin")
     nsMkdir(ns, "/tmp")
     nsMkdir(ns, "/scripts")
